@@ -43,12 +43,12 @@
  * @param mode   the counting mode, must be an exact mathematical integer
  */
 static void
-count(Field &field1, const Field &field2, double mode)
+count(Field &field1, Field const &field2, double mode)
 {
   auto missval1 = field1.missval;
   auto missval2 = field2.missval;
   auto &array1 = field1.vec_d;
-  const auto &array2 = field2.vec_d;
+  auto const &array2 = field2.vec_d;
 
   auto len = field1.size;
   if (len != field2.size) cdo_abort("Fields have different size (%s)", __func__);
@@ -128,12 +128,12 @@ count(Field &field1, const Field &field2, double mode)
  * @param compare the comparator
  */
 static void
-selcomp(Field &field1, const Field &field2, int (*compare)(double, double))
+selcomp(Field &field1, Field const &field2, int (*compare)(double, double))
 {
   auto missval1 = field1.missval;
   auto missval2 = field2.missval;
   auto &array1 = field1.vec_d;
-  const auto &array2 = field2.vec_d;
+  auto const &array2 = field2.vec_d;
 
   auto len = field1.size;
   if (len != field2.size) cdo_abort("Fields have different size (%s)", __func__);
@@ -231,30 +231,30 @@ ne(double a, double b)
 }
 
 void
-vfarnum(Field &field1, const Field &field2)
+vfarnum(Field &field1, Field const &field2)
 {
   count(field1, field2, 0.0);
 }
 
 void
-vfarnum2(Field &field1, const Field &field2)
+vfarnum2(Field &field1, Field const &field2)
 {
   count(field1, field2, 1.0);
 }
 
 void
-vfarnum3(Field &field1, const Field &field2, double n)
+vfarnum3(Field &field1, Field const &field2, double n)
 {
   count(field1, field2, n);
 }
 
 void
-vfarsel(Field &field1, const Field &field2)
+vfarsel(Field &field1, Field const &field2)
 {
   auto missval1 = field1.missval;
   auto missval2 = field2.missval;
   auto &array1 = field1.vec_d;
-  const auto &array2 = field2.vec_d;
+  auto const &array2 = field2.vec_d;
 
   auto len = field1.size;
   if (len != field2.size) cdo_abort("Fields have different gridsize (%s)", __func__);
@@ -274,37 +274,37 @@ vfarsel(Field &field1, const Field &field2)
 }
 
 void
-vfarselle(Field &field1, const Field &field2)
+vfarselle(Field &field1, Field const &field2)
 {
   selcomp(field1, field2, le);
 }
 
 void
-vfarsellt(Field &field1, const Field &field2)
+vfarsellt(Field &field1, Field const &field2)
 {
   selcomp(field1, field2, lt);
 }
 
 void
-vfarselge(Field &field1, const Field &field2)
+vfarselge(Field &field1, Field const &field2)
 {
   selcomp(field1, field2, ge);
 }
 
 void
-vfarselgt(Field &field1, const Field &field2)
+vfarselgt(Field &field1, Field const &field2)
 {
   selcomp(field1, field2, gt);
 }
 
 void
-vfarseleq(Field &field1, const Field &field2)
+vfarseleq(Field &field1, Field const &field2)
 {
   selcomp(field1, field2, eq);
 }
 
 void
-vfarselne(Field &field1, const Field &field2)
+vfarselne(Field &field1, Field const &field2)
 {
   selcomp(field1, field2, ne);
 }
@@ -346,7 +346,7 @@ vfarselgtc(Field &field, double c)
 }
 
 void
-update_hist(FieldVector2D &field, int nlevels, size_t gridsize, const std::vector<double> &yvals, bool onlyNorth)
+update_hist(FieldVector2D &field, int nlevels, size_t gridsize, std::vector<double> const &yvals, bool onlyNorth)
 {
   for (int levelID = 0; levelID < nlevels; ++levelID)
     for (size_t i = 0; i < gridsize; ++i)
@@ -391,7 +391,7 @@ define_mid_of_time(int frequency, int taxisID, int year, int month, int MaxMonth
 }
 
 void
-adjust_end_date(int nlevels, size_t gridsize, const std::vector<double> &yvals, double missval, int64_t ovdate,
+adjust_end_date(int nlevels, size_t gridsize, std::vector<double> const &yvals, double missval, int64_t ovdate,
                 const FieldVector2D &startDateWithHist, FieldVector2D &endDateWithHist)
 {
   auto ovdateSouth = std::min(cdiEncodeDate(ovdate / 10000, 6, 30), (int) ovdate);
@@ -500,7 +500,7 @@ compute_gsl(int nlevels, size_t gridsize, std::vector<double> &yvals, double mis
 
 void
 write_gsl_stream(CdoStreamID ostreamID, int otaxisID, int otsID, int ovarID1, int ovarID2, int ivlistID1, int first_var_id,
-                 FieldVector &gslDuration, FieldVector &gslFirstDay, const CdiDateTime &vDateTime, int nlevels)
+                 FieldVector &gslDuration, FieldVector &gslFirstDay, CdiDateTime const &vDateTime, int nlevels)
 {
   (void) ivlistID1;
   (void) first_var_id;
@@ -511,12 +511,12 @@ write_gsl_stream(CdoStreamID ostreamID, int otaxisID, int otsID, int ovarID1, in
   for (int levelID = 0; levelID < nlevels; ++levelID)
     {
       cdo_def_field(ostreamID, ovarID1, levelID);
-      cdo_write_field(ostreamID, gslDuration[levelID].vec_d.data(), gslDuration[levelID].numMissVals);
+      cdo_write_field(ostreamID, gslDuration[levelID]);
     }
 
   for (int levelID = 0; levelID < nlevels; ++levelID)
     {
       cdo_def_field(ostreamID, ovarID2, levelID);
-      cdo_write_field(ostreamID, gslFirstDay[levelID].vec_d.data(), gslFirstDay[levelID].numMissVals);
+      cdo_write_field(ostreamID, gslFirstDay[levelID]);
     }
 }
