@@ -7,10 +7,11 @@
 #ifndef GRIDDES_H
 #define GRIDDES_H
 
-#include <vector>
 #include <string>
 #include <cdi.h>
 
+#include "varray.h"
+
 constexpr double undefGridValue = 9.e20;
 
 // clang-format off
@@ -21,11 +22,12 @@ struct  // GridDesciption
 GridDesciption
 // clang-format on
 {
+  std::vector<int64_t> indices;
   std::vector<int> mask;
-  std::vector<double> xvals;
-  std::vector<double> yvals;
-  std::vector<double> xbounds;
-  std::vector<double> ybounds;
+  Varray<double> xvals;
+  Varray<double> yvals;
+  Varray<double> xbounds;
+  Varray<double> ybounds;
   std::vector<double> area;
   std::vector<int> reducedPoints;
   char **xcvals = nullptr;
@@ -70,24 +72,25 @@ GridDesciption
   std::string projection;
   std::string healpixOrder;
   int healpixNside = 0;
+  int refinementLevel = 0;
 };
 
 int grid_define(GridDesciption &grid);
 
 int grid_from_nc_file(const char *gridfile);
 int grid_from_h5_file(const char *gridfile);
-int grid_from_name(const std::string &gridname);
+int grid_from_name(std::string const &gridname);
 
 void write_nc_grid(const char *gridfile, int gridID, int *imask);
 
-int cdo_define_grid(const std::string &gridfile);
+int cdo_define_grid(std::string const &gridfile);
 
-int grid_read(FILE *gfp, const char *dname);  // TODO: Find better place for this
+int grid_read(std::FILE *gfp, const char *dname);  // TODO: Find better place for this
 
 int cdo_cdf_openread(const char *filename);
 void cdo_cdf_close(int nc_file_id);
-void cdo_set_grids(const char *gridarg);
+void cdo_set_grids(std::string const &gridarg);
 
-void gaussian_latitudes_in_degrees(std::vector<double> &lats, std::vector<double> &lat_bounds, size_t nlat);
+void gaussian_latitudes_in_degrees(Varray<double> &lats, Varray<double> &lat_bounds);
 
 #endif /* GRIDDES_H */
