@@ -15,7 +15,7 @@ gcLLtoXYZ(double lon, double lat, std::array<double, 3> &xyz)
 }
 
 static inline void
-gcLLtoXYZ(double lon, double lat, double *xyz)
+gcLLtoXYZ(double lon, double lat, double (&xyz)[3])
 {
   auto cos_lat = std::cos(lat);
   xyz[0] = cos_lat * std::cos(lon);
